@@ -1,6 +1,6 @@
 use strict; use warnings;
 package Inline::C;
-our $VERSION = '0.62';
+our $VERSION = '0.65';
 
 use Inline 0.56;
 use Config;
@@ -385,8 +385,8 @@ sub get_parser {
     my $o = shift;
     Inline::C::_parser_test($o->{CONFIG}{DIRECTORY}, "Inline::C::get_parser called\n")
         if $o->{CONFIG}{_TESTING};
-    require Inline::C::ParseRecDescent;
-    Inline::C::ParseRecDescent::get_parser($o);
+    require Inline::C::Parser::RecDescent;
+    Inline::C::Parser::RecDescent::get_parser($o);
 }
 
 #==============================================================================
@@ -777,7 +777,6 @@ sub write_Makefile_PL {
     my $i = 0;
     for (@{$o->{ILSM}{MAKEFILE}{TYPEMAPS}}) {
         $o->{ILSM}{xsubppargs} .= "-typemap \"$_\" ";
-        $o->{ILSM}{MAKEFILE}{TYPEMAPS}->[$i++] = fix_space($_);
     }
 
     my %options = (
@@ -956,7 +955,6 @@ sub fix_make {
             $fix = $fixes{$1}
         ) {
             my $fixed = $o->{ILSM}{$fix};
-            $fixed = fix_space($fixed) if $fix eq 'install_lib';
             print MAKEFILE "$1 = $fixed\n";
         }
         else {
@@ -1037,11 +1035,6 @@ sub quote_space {
     $_[0] = $out;
 }
 
-sub fix_space {
-    $_[0] =~ s/ /\\ /g if $_[0] =~ / /;
-    $_[0];
-}
-
 #==============================================================================
 # This routine used by C/t/09parser to test that the expected parser is in use
 #==============================================================================
